raytraverse (|release|)
======================================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :hidden:

   scene
   mapper
   renderer

   sampler
   lightfield
   integrator
   craytraverse
   draw
   io
   metric
   plot
   skycalc
   translate
   cli

.. toctree::
   :maxdepth: 3
   :hidden:

   history
   genindex
   search
   todo
